@@ -40,12 +40,12 @@ class TestValidationActions(TestCase):
         self.assertEqual(validations_list.list_validations(),
                          (self.column_name, [('my_val1',
                                               'My Validation One Name',
-                                              ['prep', 'pre-deployment'],
+                                              ['prep', 'pre-deployment', 'no-op', 'post'],
                                               ['os', 'system', 'ram'],
                                               ['product1']),
                                              ('my_val2',
                                               'My Validation Two Name',
-                                              ['prep', 'pre-introspection'],
+                                              ['prep', 'pre-introspection', 'post', 'pre'],
                                               ['networking'],
                                               ['product1'])]))
 
@@ -104,13 +104,14 @@ class TestValidationActions(TestCase):
             'extra_vars': None,
             'limit_hosts': '!cloud1',
             'extra_env_variables': None,
-            'ansible_cfg': None,
+            'ansible_cfg_file': None,
             'gathering_policy': 'explicit',
             'ansible_artifact_path': '/var/log/validations/artifacts/123_fake.yaml_time',
             'log_path': '/var/log/validations',
             'run_async': False,
             'python_interpreter': None,
-            'ssh_user': None
+            'ssh_user': None,
+            'validation_cfg_file': None
         }
 
         playbook = ['fake.yaml']
@@ -164,13 +165,14 @@ class TestValidationActions(TestCase):
             'extra_vars': None,
             'limit_hosts': '!cloud1,cloud,!cloud2',
             'extra_env_variables': None,
-            'ansible_cfg': None,
+            'ansible_cfg_file': None,
             'gathering_policy': 'explicit',
             'ansible_artifact_path': '/var/log/validations/artifacts/123_fake.yaml_time',
             'log_path': '/var/log/validations',
             'run_async': False,
             'python_interpreter': None,
-            'ssh_user': None
+            'ssh_user': None,
+            'validation_cfg_file': None
         }
 
         playbook = ['fake.yaml']
@@ -380,9 +382,9 @@ class TestValidationActions(TestCase):
         col, values = v_actions.group_information('512e')
         self.assertEqual(col, ('Groups', 'Description',
                                'Number of Validations'))
-        self.assertEqual(values, [('no-op', 'noop-foo', 2),
+        self.assertEqual(values, [('no-op', 'noop-foo', 1),
                                   ('post', 'post-foo', 2),
-                                  ('pre', 'pre-foo', 2)])
+                                  ('pre', 'pre-foo', 1)])
 
     @mock.patch('six.moves.builtins.open')
     def test_show_validations_parameters_wrong_validations_type(self, mock_open):
