@@ -188,8 +188,8 @@ class ValidationActions(object):
             'cloud2,!cloud1'
 
         """
-        hosts = skip_list[playbook].get('hosts')
-        if hosts == 'ALL' or hosts is None:
+        hosts = skip_list[playbook].get('hosts', 'all')
+        if hosts.lower() == 'all':
             return None
         else:
             _hosts = ['!{}'.format(hosts)]
@@ -267,7 +267,8 @@ class ValidationActions(object):
                         log_path=constants.VALIDATIONS_LOG_BASEDIR,
                         python_interpreter=None, skip_list=None,
                         callback_whitelist=None,
-                        output_callback='validation_stdout', ssh_user=None):
+                        output_callback='validation_stdout', ssh_user=None,
+                        validation_config=None):
         """Run one or multiple validations by name(s), by group(s) or by
         product(s)
 
@@ -336,6 +337,9 @@ class ValidationActions(object):
         :rtype: ``list``
         :param ssh_user: Ssh user for Ansible remote connection
         :type ssh_user: ``string``
+        :param validation_config: A dictionary of configuration for Validation
+                                  loaded from an validation.cfg file.
+        :type validation_config: ``dict``
 
         :Example:
 
@@ -424,13 +428,14 @@ class ValidationActions(object):
                             extra_vars=extra_vars,
                             limit_hosts=_hosts,
                             extra_env_variables=extra_env_vars,
-                            ansible_cfg=ansible_cfg,
+                            ansible_cfg_file=ansible_cfg,
                             gathering_policy='explicit',
                             ansible_artifact_path=artifacts_dir,
                             log_path=log_path,
                             run_async=run_async,
                             python_interpreter=python_interpreter,
-                            ssh_user=ssh_user)
+                            ssh_user=ssh_user,
+                            validation_cfg_file=validation_config)
                 else:
                     _playbook, _rc, _status = run_ansible.run(
                         workdir=artifacts_dir,
@@ -445,21 +450,31 @@ class ValidationActions(object):
                         extra_vars=extra_vars,
                         limit_hosts=_hosts,
                         extra_env_variables=extra_env_vars,
-                        ansible_cfg=ansible_cfg,
+                        ansible_cfg_file=ansible_cfg,
                         gathering_policy='explicit',
                         ansible_artifact_path=artifacts_dir,
                         log_path=log_path,
                         run_async=run_async,
                         python_interpreter=python_interpreter,
-                        ssh_user=ssh_user)
+                        ssh_user=ssh_user,
+                        validation_cfg_file=validation_config)
                 results.append({'playbook': _playbook,
                                 'rc_code': _rc,
                                 'status': _status,
                                 'validations': _playbook.split('.')[0],
                                 'UUID': validation_uuid,
                                 })
+                # Print hosts which has been skipped:
+                if _hosts:
+                    skipped_hosts = [h.replace('!', '')
+                                     for h in _hosts.split(',') if '!' in h]
+                    if skipped_hosts:
+                        msg = ("Validation {} has been skipped "
+                               "on hosts: {}").format(_play,
+                                                      ','.join(skipped_hosts))
+                        self.log.info(msg)
             else:
-                self.log.debug('Skipping Validations: {}'.format(playbook))
+                self.log.info('Skipping Validations: {}'.format(playbook))
 
         if run_async:
             return results
@@ -502,14 +517,23 @@ class ValidationActions(object):
           ('group3', 'Description of group3', 1)])
         """
         val_gp = Group(groups)
-        group = val_gp.get_formated_group
+        group_definitions = val_gp.get_formated_group
 
         group_info = []
-        # Get validations number by groups
-        for gp in group:
-            validations = v_utils.parse_all_validations_on_disk(
-                self.validation_path, gp[0])
-            group_info.append((gp[0], gp[1], len(validations)))
+
+        validations = v_utils.parse_all_validations_on_disk(
+                path=self.validation_path,
+                groups=[group[0] for group in group_definitions])
+
+        # Get validations number by group
+        for group in group_definitions:
+            n_matches = len(
+                [val for val in validations if group[0] in val['groups']])
+            group_info.append((
+                group[0],
+                group[1],
+                n_matches))
+
         column_name = ("Groups", "Description", "Number of Validations")
         return (column_name, group_info)
 
